@@ -16,3 +16,16 @@
 # with this program. If not, see <http://www.gnu.org/licenses/>.
 
 """cubicweb-squareui views/forms/actions/components for web ui"""
+from cubicweb.web.views.boxes import ContextualBoxLayout, contextual
+
+_ = unicode
+
+class SimpleBoxContextFreeBoxLayout(ContextualBoxLayout):
+    __select__ = ~contextual()
+    cssclass = 'contextFreeBox'
+    __regid__ = 'simple-layout'
+
+    def render(self, w):
+        if self.init_rendering():
+            view = self.cw_extra_kwargs['view']
+            view.render_body(w)
