@@ -42,7 +42,6 @@ def template_html_header(self, content_type, page_title,
     w = self.whead
     lang = self._cw.lang
     self.write_doctype()
-    # explictly close the <base> tag to avoid IE 6 bugs while browsing DOM
     self._cw.html_headers.define_var('BASE_URL', self._cw.base_url())
     self._cw.html_headers.define_var('DATA_URL', self._cw.datadir_url)
     w(u'<meta http-equiv="content-type" content="%s; charset=%s"/>\n'
@@ -50,13 +49,6 @@ def template_html_header(self, content_type, page_title,
     w(u'<meta name="viewport" content="initial-scale=1.0; '
       u'maximum-scale=1.0; width=device-width; "/>')
     w(u'\n'.join(additional_headers) + u'\n')
-    # FIXME this is a quick option to make cw work in IE9
-    # you'll lose all IE9 functionality, the browser will act as IE8.
-    w(u'<meta http-equiv="X-UA-Compatible" content="IE=8" />\n')
-    w(u'<!-- Le HTML5 shim, for IE6-8 support of HTML elements -->\n'
-      u'  <!--[if lt IE 9]>\n'
-      u'        <script src="%s"></script>\n'
-      u'  <![endif]-->\n' % self._cw.data_url('js/html5.js'))
     self.wview('htmlheader', rset=self.cw_rset)
     if page_title:
         w(u'<title>%s</title>\n' % xml_escape(page_title))
