@@ -30,7 +30,7 @@ class HideAsidesBar(HeaderComponent):
     icon_css_cls = 'glyphicon glyphicon-align-justify'
 
     def render(self, w):
-        w(u'''<button class="btn btn-default" id="cw-aside-toggle" class="navbar-toggle"
+        w(u'''<button class="btn btn-default navbar-toggle" id="cw-aside-toggle"
               onclick="cw.cubes.squareui.toggleLeftColumn()" title="%(label)s">
               <span class="%(icon_class)s"></span>
               </button>''' % {
